﻿using Hotline.Application.Snapshot;
using Hotline.Share.Dtos;
using Hotline.Share.Dtos.Snapshot;
using Microsoft.AspNetCore.Mvc;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Tools;
using Hotline.Snapshot.Interfaces;
using Hotline.Caching.Interfaces;
using XF.Utility.EnumExtensions;
using Hotline.Share.Enums.Snapshot;

namespace Hotline.Api.Controllers.Snapshot;

public class RedPackController : BaseController
{
    private readonly IRedPackApplication _redPackApplication;
    private readonly IIndustryRepository _industryRepository;
    private readonly ISystemDicDataCacheManager _sysDic;
    private readonly ISnapshotSMSTemplateRepository _snapshotSMSTemplateRepository;

    public RedPackController(IRedPackApplication redPackApplication, IIndustryRepository industryRepository, ISystemDicDataCacheManager sysDic, ISnapshotSMSTemplateRepository snapshotSMSTemplateRepository)
    {
        _redPackApplication = redPackApplication;
        _industryRepository = industryRepository;
        _sysDic = sysDic;
        _snapshotSMSTemplateRepository = snapshotSMSTemplateRepository;
    }

    /// <summary>
    /// 获取市民红包审批列表
    /// </summary>
    /// <returns></returns>
    [HttpGet("audit")]
    public async Task<PagedDto<SnapshotOrderAuditItemsOutDto>> GetRedPackAuditItemsAsync([FromQuery] SnapshotOrderAuditItemsInDto dto)
        => (await _redPackApplication.GetRedPackAuditItemsAsync(dto).ToPagedListAsync(dto)).ToPaged();

    /// <summary>
    /// 获取审核详情
    /// </summary>
    /// <param name="id">工单Id</param>
    /// <returns></returns>
    [HttpGet("audit/{id}")]
    public async Task<SnapshotOrderAuditDetailOutDto> GetRedPackAuditDetailAsync([FromQuery]string id)
        => await _redPackApplication.GetRedPackAuditDetailAsync(id);

    /// <summary>
    /// 获取审核短信模板
    /// </summary>
    /// <returns></returns>
    [HttpGet("audit/sms_template")]
    public async Task<IList<GetRedPackAuditSMSTemplateOutDto>> GetRedPackAuditSMSTemplateAsync([FromQuery]GetRedPackAuditSMSTemplateInDto dto)
        => await _redPackApplication.GetRedPackAuditSMSTemplateAsync(dto);

    /// <summary>
    /// 红包审批页面基础数据
    /// </summary>
    /// <returns></returns>
    [HttpGet("audit/basedata")]
    public async Task<Dictionary<string, object>> GetAuditBaseDataAsync()
    {
        var industry = await _industryRepository.Queryable()
            .Select(m => new { m.Id, m.Name })
            .ToListAsync();

        var configAmount = await _industryRepository.Queryable()
            .Select(m => m.CitizenReadPackAmount)
            .Distinct()
            .ToListAsync();
        var sms = await _snapshotSMSTemplateRepository.Queryable()
            .ToListAsync();
        return new Dictionary<string, object>
        {
            { "industry", industry },
            { "configAmount",  configAmount },
            { "status", EnumExts.GetDescriptions<ERedPackAuditStatus>() }
        };
    }
}
